# Copyright 2024 Cisco Systems, Inc. and its affiliates
from dataclasses import dataclass
from dataclasses import field as _field
from typing import Any, List, Literal, Optional, Union

GlobalOptionTypeDef = Literal["global"]

VariableOptionTypeDef = Literal["variable"]

DefaultOptionTypeDef = Literal["default"]

MetricTypeDef = Literal["type1", "type2"]

RedistributeProtocolDef = Literal["bgp", "connected", "eigrp", "static"]

RouterLsaAdTypeDef = Literal["administrative", "on-startup"]

AreaATypeDef = Literal["nssa", "stub"]

AreaInterfaceNetworkDef = Literal[
    "broadcast", "non-broadcast", "point-to-multipoint", "point-to-point"
]

DefaultAreaInterfaceNetworkDef = Literal["broadcast"]

AreaInterfaceTypeDef = Literal["message-digest"]

Ipv4SubnetMaskDef = Literal[
    "0.0.0.0",
    "128.0.0.0",
    "192.0.0.0",
    "224.0.0.0",
    "240.0.0.0",
    "248.0.0.0",
    "252.0.0.0",
    "254.0.0.0",
    "255.0.0.0",
    "255.128.0.0",
    "255.192.0.0",
    "255.224.0.0",
    "255.240.0.0",
    "255.252.0.0",
    "255.254.0.0",
    "255.255.0.0",
    "255.255.128.0",
    "255.255.192.0",
    "255.255.224.0",
    "255.255.240.0",
    "255.255.248.0",
    "255.255.252.0",
    "255.255.254.0",
    "255.255.255.0",
    "255.255.255.128",
    "255.255.255.192",
    "255.255.255.224",
    "255.255.255.240",
    "255.255.255.248",
    "255.255.255.252",
    "255.255.255.254",
    "255.255.255.255",
]


@dataclass
class OneOfProcessIdOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfProcessIdOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfRouterIdOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str


@dataclass
class OneOfRouterIdOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfRouterIdOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfReferenceBandwidthOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfReferenceBandwidthOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfReferenceBandwidthOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfRfc1583OptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfRfc1583OptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfRfc1583OptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfOriginateOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfOriginateOptionsDef2:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfAlwaysOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfAlwaysOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAlwaysOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfMetricOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfMetricOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfMetricOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfMetricTypeOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: MetricTypeDef  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfMetricTypeOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfMetricTypeOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfExternalOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfExternalOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfExternalOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfInterAreaOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfInterAreaOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfInterAreaOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfIntraAreaOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfIntraAreaOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfIntraAreaOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfDelayOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfDelayOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfDelayOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfInitialHoldOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfInitialHoldOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfInitialHoldOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfMaxHoldOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfMaxHoldOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfMaxHoldOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfRedistributeProtocolOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: RedistributeProtocolDef  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfRedistributeProtocolOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfRoutePolicyNameOptionsDef1:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class RefId:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str


@dataclass
class OneOfRoutePolicyNameOptionsDef2:
    ref_id: RefId = _field(metadata={"alias": "refId"})


@dataclass
class Redistribute:
    protocol: Union[OneOfRedistributeProtocolOptionsDef1, OneOfRedistributeProtocolOptionsDef2]
    route_policy: Optional[
        Union[OneOfRoutePolicyNameOptionsDef1, OneOfRoutePolicyNameOptionsDef2]
    ] = _field(default=None, metadata={"alias": "routePolicy"})


@dataclass
class OneOfRouterLsaAdTypeOptionsDef:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: RouterLsaAdTypeDef  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfRouterLsaTimeOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfRouterLsaTimeOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class RouterLsa:
    ad_type: OneOfRouterLsaAdTypeOptionsDef = _field(metadata={"alias": "adType"})
    time: Optional[Union[OneOfRouterLsaTimeOptionsDef1, OneOfRouterLsaTimeOptionsDef2]] = _field(
        default=None
    )


@dataclass
class OneOfAreaANumOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaANumOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaATypeOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: AreaATypeDef  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfAreaATypeOptionsDef2:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfAreaNoSummaryOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfAreaNoSummaryOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaNoSummaryOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfAreaInterfaceNameOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str


@dataclass
class OneOfAreaInterfaceNameOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceHelloIntervalOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceHelloIntervalOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceHelloIntervalOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceDeadIntervalOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceDeadIntervalOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceDeadIntervalOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceRetransmitIntervalOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceRetransmitIntervalOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceRetransmitIntervalOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceCostOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceCostOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceCostOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfAreaInterfacePriorityOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfacePriorityOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfacePriorityOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceNetworkOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: AreaInterfaceNetworkDef


@dataclass
class OneOfAreaInterfaceNetworkOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceNetworkOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: DefaultAreaInterfaceNetworkDef  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfAreaInterfacePassiveInterfaceOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfAreaInterfacePassiveInterfaceOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfacePassiveInterfaceOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfAreaInterfaceTypeOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: AreaInterfaceTypeDef  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfAreaInterfaceTypeOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceTypeOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfAreaInterfaceMessageDigestKeyOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaInterfaceMessageDigestKeyOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaInterfaceMd5OptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str


@dataclass
class OneOfAreaInterfaceMd5OptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class Interface:
    cost: Optional[
        Union[
            OneOfAreaInterfaceCostOptionsDef1,
            OneOfAreaInterfaceCostOptionsDef2,
            OneOfAreaInterfaceCostOptionsDef3,
        ]
    ] = _field(default=None)
    dead_interval: Optional[
        Union[
            OneOfAreaInterfaceDeadIntervalOptionsDef1,
            OneOfAreaInterfaceDeadIntervalOptionsDef2,
            OneOfAreaInterfaceDeadIntervalOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "deadInterval"})
    hello_interval: Optional[
        Union[
            OneOfAreaInterfaceHelloIntervalOptionsDef1,
            OneOfAreaInterfaceHelloIntervalOptionsDef2,
            OneOfAreaInterfaceHelloIntervalOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "helloInterval"})
    md5: Optional[Union[OneOfAreaInterfaceMd5OptionsDef1, OneOfAreaInterfaceMd5OptionsDef2]] = (
        _field(default=None)
    )
    message_digest_key: Optional[
        Union[
            OneOfAreaInterfaceMessageDigestKeyOptionsDef1,
            OneOfAreaInterfaceMessageDigestKeyOptionsDef2,
        ]
    ] = _field(default=None, metadata={"alias": "messageDigestKey"})
    name: Optional[Union[OneOfAreaInterfaceNameOptionsDef1, OneOfAreaInterfaceNameOptionsDef2]] = (
        _field(default=None)
    )
    network: Optional[
        Union[
            OneOfAreaInterfaceNetworkOptionsDef1,
            OneOfAreaInterfaceNetworkOptionsDef2,
            OneOfAreaInterfaceNetworkOptionsDef3,
        ]
    ] = _field(default=None)
    passive_interface: Optional[
        Union[
            OneOfAreaInterfacePassiveInterfaceOptionsDef1,
            OneOfAreaInterfacePassiveInterfaceOptionsDef2,
            OneOfAreaInterfacePassiveInterfaceOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "passiveInterface"})
    priority: Optional[
        Union[
            OneOfAreaInterfacePriorityOptionsDef1,
            OneOfAreaInterfacePriorityOptionsDef2,
            OneOfAreaInterfacePriorityOptionsDef3,
        ]
    ] = _field(default=None)
    retransmit_interval: Optional[
        Union[
            OneOfAreaInterfaceRetransmitIntervalOptionsDef1,
            OneOfAreaInterfaceRetransmitIntervalOptionsDef2,
            OneOfAreaInterfaceRetransmitIntervalOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "retransmitInterval"})
    type_: Optional[
        Union[
            OneOfAreaInterfaceTypeOptionsDef1,
            OneOfAreaInterfaceTypeOptionsDef2,
            OneOfAreaInterfaceTypeOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "type"})


@dataclass
class OneOfAreaRangeIpV4AddressOptionsDef1:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaRangeIpV4AddressOptionsDef2:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str


@dataclass
class OneOfAreaRangeIpV4SubnetMaskOptionsDef1:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaRangeIpV4SubnetMaskOptionsDef2:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: Ipv4SubnetMaskDef  # pytype: disable=annotation-type-mismatch


@dataclass
class Address:
    """
    Set matching prefix
    """

    ip_address: Optional[
        Union[OneOfAreaRangeIpV4AddressOptionsDef1, OneOfAreaRangeIpV4AddressOptionsDef2]
    ] = _field(default=None, metadata={"alias": "ipAddress"})
    subnet_mask: Optional[
        Union[OneOfAreaRangeIpV4SubnetMaskOptionsDef1, OneOfAreaRangeIpV4SubnetMaskOptionsDef2]
    ] = _field(default=None, metadata={"alias": "subnetMask"})


@dataclass
class OneOfAreaRangeCostOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: int


@dataclass
class OneOfAreaRangeCostOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaRangeCostOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch


@dataclass
class OneOfAreaRangeNoAdvertiseOptionsDef1:
    option_type: GlobalOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class OneOfAreaRangeNoAdvertiseOptionsDef2:
    option_type: VariableOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: str
    default: Optional[str] = _field(default=None)
    description: Optional[str] = _field(default=None)


@dataclass
class OneOfAreaRangeNoAdvertiseOptionsDef3:
    option_type: DefaultOptionTypeDef = _field(
        metadata={"alias": "optionType"}
    )  # pytype: disable=annotation-type-mismatch
    value: bool


@dataclass
class Range:
    # Set matching prefix
    address: Optional[Address] = _field(default=None)
    cost: Optional[
        Union[
            OneOfAreaRangeCostOptionsDef1,
            OneOfAreaRangeCostOptionsDef2,
            OneOfAreaRangeCostOptionsDef3,
        ]
    ] = _field(default=None)
    no_advertise: Optional[
        Union[
            OneOfAreaRangeNoAdvertiseOptionsDef1,
            OneOfAreaRangeNoAdvertiseOptionsDef2,
            OneOfAreaRangeNoAdvertiseOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "noAdvertise"})


@dataclass
class Area:
    a_num: Union[OneOfAreaANumOptionsDef1, OneOfAreaANumOptionsDef2] = _field(
        metadata={"alias": "aNum"}
    )
    a_type: Optional[Union[OneOfAreaATypeOptionsDef1, OneOfAreaATypeOptionsDef2]] = _field(
        default=None, metadata={"alias": "aType"}
    )
    # Set OSPF interface parameters
    interface: Optional[List[Interface]] = _field(default=None)
    no_summary: Optional[
        Union[
            OneOfAreaNoSummaryOptionsDef1,
            OneOfAreaNoSummaryOptionsDef2,
            OneOfAreaNoSummaryOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "noSummary"})
    # Summarize OSPF routes at an area boundary
    range: Optional[List[Range]] = _field(default=None)


@dataclass
class OspfData:
    process_id: Union[OneOfProcessIdOptionsDef1, OneOfProcessIdOptionsDef2] = _field(
        metadata={"alias": "processId"}
    )
    always: Optional[
        Union[OneOfAlwaysOptionsDef1, OneOfAlwaysOptionsDef2, OneOfAlwaysOptionsDef3]
    ] = _field(default=None)
    # Configure OSPF area
    area: Optional[List[Area]] = _field(default=None)
    delay: Optional[Union[OneOfDelayOptionsDef1, OneOfDelayOptionsDef2, OneOfDelayOptionsDef3]] = (
        _field(default=None)
    )
    external: Optional[
        Union[OneOfExternalOptionsDef1, OneOfExternalOptionsDef2, OneOfExternalOptionsDef3]
    ] = _field(default=None)
    initial_hold: Optional[
        Union[OneOfInitialHoldOptionsDef1, OneOfInitialHoldOptionsDef2, OneOfInitialHoldOptionsDef3]
    ] = _field(default=None, metadata={"alias": "initialHold"})
    inter_area: Optional[
        Union[OneOfInterAreaOptionsDef1, OneOfInterAreaOptionsDef2, OneOfInterAreaOptionsDef3]
    ] = _field(default=None, metadata={"alias": "interArea"})
    intra_area: Optional[
        Union[OneOfIntraAreaOptionsDef1, OneOfIntraAreaOptionsDef2, OneOfIntraAreaOptionsDef3]
    ] = _field(default=None, metadata={"alias": "intraArea"})
    max_hold: Optional[
        Union[OneOfMaxHoldOptionsDef1, OneOfMaxHoldOptionsDef2, OneOfMaxHoldOptionsDef3]
    ] = _field(default=None, metadata={"alias": "maxHold"})
    metric: Optional[
        Union[OneOfMetricOptionsDef1, OneOfMetricOptionsDef2, OneOfMetricOptionsDef3]
    ] = _field(default=None)
    metric_type: Optional[
        Union[OneOfMetricTypeOptionsDef1, OneOfMetricTypeOptionsDef2, OneOfMetricTypeOptionsDef3]
    ] = _field(default=None, metadata={"alias": "metricType"})
    originate: Optional[Union[OneOfOriginateOptionsDef1, OneOfOriginateOptionsDef2]] = _field(
        default=None
    )
    # Redistribute routes
    redistribute: Optional[List[Redistribute]] = _field(default=None)
    reference_bandwidth: Optional[
        Union[
            OneOfReferenceBandwidthOptionsDef1,
            OneOfReferenceBandwidthOptionsDef2,
            OneOfReferenceBandwidthOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "referenceBandwidth"})
    rfc1583: Optional[
        Union[OneOfRfc1583OptionsDef1, OneOfRfc1583OptionsDef2, OneOfRfc1583OptionsDef3]
    ] = _field(default=None)
    route_policy: Optional[
        Union[OneOfRoutePolicyNameOptionsDef1, OneOfRoutePolicyNameOptionsDef2]
    ] = _field(default=None, metadata={"alias": "routePolicy"})
    router_id: Optional[
        Union[OneOfRouterIdOptionsDef1, OneOfRouterIdOptionsDef2, OneOfRouterIdOptionsDef3]
    ] = _field(default=None, metadata={"alias": "routerId"})
    # Advertise own router LSA with infinite distance
    router_lsa: Optional[List[RouterLsa]] = _field(default=None, metadata={"alias": "routerLsa"})


@dataclass
class Payload:
    """
    Routing OSPF feature schema
    """

    data: OspfData
    name: str
    description: Optional[str] = _field(default=None)
    metadata: Optional[Any] = _field(default=None)


@dataclass
class Data:
    # User who last created this.
    created_by: Optional[str] = _field(default=None, metadata={"alias": "createdBy"})
    # Timestamp of creation
    created_on: Optional[int] = _field(default=None, metadata={"alias": "createdOn"})
    # User who last updated this.
    last_updated_by: Optional[str] = _field(default=None, metadata={"alias": "lastUpdatedBy"})
    # Timestamp of last update
    last_updated_on: Optional[int] = _field(default=None, metadata={"alias": "lastUpdatedOn"})
    parcel_id: Optional[str] = _field(default=None, metadata={"alias": "parcelId"})
    parcel_type: Optional[str] = _field(default=None, metadata={"alias": "parcelType"})
    # Routing OSPF feature schema
    payload: Optional[Payload] = _field(default=None)


@dataclass
class GetListSdRoutingTransportRoutingOspfPayload:
    data: Optional[List[Data]] = _field(default=None)


@dataclass
class CreateSdroutingTransportRoutingOspfFeaturePostResponse:
    """
    Profile Parcel POST Response schema
    """

    parcel_id: str = _field(metadata={"alias": "parcelId"})
    metadata: Optional[Any] = _field(default=None)


@dataclass
class RoutingOspfData:
    process_id: Union[OneOfProcessIdOptionsDef1, OneOfProcessIdOptionsDef2] = _field(
        metadata={"alias": "processId"}
    )
    always: Optional[
        Union[OneOfAlwaysOptionsDef1, OneOfAlwaysOptionsDef2, OneOfAlwaysOptionsDef3]
    ] = _field(default=None)
    # Configure OSPF area
    area: Optional[List[Area]] = _field(default=None)
    delay: Optional[Union[OneOfDelayOptionsDef1, OneOfDelayOptionsDef2, OneOfDelayOptionsDef3]] = (
        _field(default=None)
    )
    external: Optional[
        Union[OneOfExternalOptionsDef1, OneOfExternalOptionsDef2, OneOfExternalOptionsDef3]
    ] = _field(default=None)
    initial_hold: Optional[
        Union[OneOfInitialHoldOptionsDef1, OneOfInitialHoldOptionsDef2, OneOfInitialHoldOptionsDef3]
    ] = _field(default=None, metadata={"alias": "initialHold"})
    inter_area: Optional[
        Union[OneOfInterAreaOptionsDef1, OneOfInterAreaOptionsDef2, OneOfInterAreaOptionsDef3]
    ] = _field(default=None, metadata={"alias": "interArea"})
    intra_area: Optional[
        Union[OneOfIntraAreaOptionsDef1, OneOfIntraAreaOptionsDef2, OneOfIntraAreaOptionsDef3]
    ] = _field(default=None, metadata={"alias": "intraArea"})
    max_hold: Optional[
        Union[OneOfMaxHoldOptionsDef1, OneOfMaxHoldOptionsDef2, OneOfMaxHoldOptionsDef3]
    ] = _field(default=None, metadata={"alias": "maxHold"})
    metric: Optional[
        Union[OneOfMetricOptionsDef1, OneOfMetricOptionsDef2, OneOfMetricOptionsDef3]
    ] = _field(default=None)
    metric_type: Optional[
        Union[OneOfMetricTypeOptionsDef1, OneOfMetricTypeOptionsDef2, OneOfMetricTypeOptionsDef3]
    ] = _field(default=None, metadata={"alias": "metricType"})
    originate: Optional[Union[OneOfOriginateOptionsDef1, OneOfOriginateOptionsDef2]] = _field(
        default=None
    )
    # Redistribute routes
    redistribute: Optional[List[Redistribute]] = _field(default=None)
    reference_bandwidth: Optional[
        Union[
            OneOfReferenceBandwidthOptionsDef1,
            OneOfReferenceBandwidthOptionsDef2,
            OneOfReferenceBandwidthOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "referenceBandwidth"})
    rfc1583: Optional[
        Union[OneOfRfc1583OptionsDef1, OneOfRfc1583OptionsDef2, OneOfRfc1583OptionsDef3]
    ] = _field(default=None)
    route_policy: Optional[
        Union[OneOfRoutePolicyNameOptionsDef1, OneOfRoutePolicyNameOptionsDef2]
    ] = _field(default=None, metadata={"alias": "routePolicy"})
    router_id: Optional[
        Union[OneOfRouterIdOptionsDef1, OneOfRouterIdOptionsDef2, OneOfRouterIdOptionsDef3]
    ] = _field(default=None, metadata={"alias": "routerId"})
    # Advertise own router LSA with infinite distance
    router_lsa: Optional[List[RouterLsa]] = _field(default=None, metadata={"alias": "routerLsa"})


@dataclass
class CreateSdroutingTransportRoutingOspfFeaturePostRequest:
    """
    Routing OSPF feature schema
    """

    data: RoutingOspfData
    name: str
    description: Optional[str] = _field(default=None)
    metadata: Optional[Any] = _field(default=None)


@dataclass
class GetSingleSdRoutingTransportRoutingOspfPayload:
    # User who last created this.
    created_by: Optional[str] = _field(default=None, metadata={"alias": "createdBy"})
    # Timestamp of creation
    created_on: Optional[int] = _field(default=None, metadata={"alias": "createdOn"})
    # User who last updated this.
    last_updated_by: Optional[str] = _field(default=None, metadata={"alias": "lastUpdatedBy"})
    # Timestamp of last update
    last_updated_on: Optional[int] = _field(default=None, metadata={"alias": "lastUpdatedOn"})
    parcel_id: Optional[str] = _field(default=None, metadata={"alias": "parcelId"})
    parcel_type: Optional[str] = _field(default=None, metadata={"alias": "parcelType"})
    # Routing OSPF feature schema
    payload: Optional[Payload] = _field(default=None)


@dataclass
class EditSdroutingTransportRoutingOspfFeaturePutResponse:
    """
    Profile Parcel PUT Response schema
    """

    id: str
    metadata: Optional[Any] = _field(default=None)


@dataclass
class TransportRoutingOspfData:
    process_id: Union[OneOfProcessIdOptionsDef1, OneOfProcessIdOptionsDef2] = _field(
        metadata={"alias": "processId"}
    )
    always: Optional[
        Union[OneOfAlwaysOptionsDef1, OneOfAlwaysOptionsDef2, OneOfAlwaysOptionsDef3]
    ] = _field(default=None)
    # Configure OSPF area
    area: Optional[List[Area]] = _field(default=None)
    delay: Optional[Union[OneOfDelayOptionsDef1, OneOfDelayOptionsDef2, OneOfDelayOptionsDef3]] = (
        _field(default=None)
    )
    external: Optional[
        Union[OneOfExternalOptionsDef1, OneOfExternalOptionsDef2, OneOfExternalOptionsDef3]
    ] = _field(default=None)
    initial_hold: Optional[
        Union[OneOfInitialHoldOptionsDef1, OneOfInitialHoldOptionsDef2, OneOfInitialHoldOptionsDef3]
    ] = _field(default=None, metadata={"alias": "initialHold"})
    inter_area: Optional[
        Union[OneOfInterAreaOptionsDef1, OneOfInterAreaOptionsDef2, OneOfInterAreaOptionsDef3]
    ] = _field(default=None, metadata={"alias": "interArea"})
    intra_area: Optional[
        Union[OneOfIntraAreaOptionsDef1, OneOfIntraAreaOptionsDef2, OneOfIntraAreaOptionsDef3]
    ] = _field(default=None, metadata={"alias": "intraArea"})
    max_hold: Optional[
        Union[OneOfMaxHoldOptionsDef1, OneOfMaxHoldOptionsDef2, OneOfMaxHoldOptionsDef3]
    ] = _field(default=None, metadata={"alias": "maxHold"})
    metric: Optional[
        Union[OneOfMetricOptionsDef1, OneOfMetricOptionsDef2, OneOfMetricOptionsDef3]
    ] = _field(default=None)
    metric_type: Optional[
        Union[OneOfMetricTypeOptionsDef1, OneOfMetricTypeOptionsDef2, OneOfMetricTypeOptionsDef3]
    ] = _field(default=None, metadata={"alias": "metricType"})
    originate: Optional[Union[OneOfOriginateOptionsDef1, OneOfOriginateOptionsDef2]] = _field(
        default=None
    )
    # Redistribute routes
    redistribute: Optional[List[Redistribute]] = _field(default=None)
    reference_bandwidth: Optional[
        Union[
            OneOfReferenceBandwidthOptionsDef1,
            OneOfReferenceBandwidthOptionsDef2,
            OneOfReferenceBandwidthOptionsDef3,
        ]
    ] = _field(default=None, metadata={"alias": "referenceBandwidth"})
    rfc1583: Optional[
        Union[OneOfRfc1583OptionsDef1, OneOfRfc1583OptionsDef2, OneOfRfc1583OptionsDef3]
    ] = _field(default=None)
    route_policy: Optional[
        Union[OneOfRoutePolicyNameOptionsDef1, OneOfRoutePolicyNameOptionsDef2]
    ] = _field(default=None, metadata={"alias": "routePolicy"})
    router_id: Optional[
        Union[OneOfRouterIdOptionsDef1, OneOfRouterIdOptionsDef2, OneOfRouterIdOptionsDef3]
    ] = _field(default=None, metadata={"alias": "routerId"})
    # Advertise own router LSA with infinite distance
    router_lsa: Optional[List[RouterLsa]] = _field(default=None, metadata={"alias": "routerLsa"})


@dataclass
class EditSdroutingTransportRoutingOspfFeaturePutRequest:
    """
    Routing OSPF feature schema
    """

    data: TransportRoutingOspfData
    name: str
    description: Optional[str] = _field(default=None)
    metadata: Optional[Any] = _field(default=None)
